import React, { Component } from 'react';
import { View, ScrollView, Dimensions, } from 'react-native';
import * as typings from './index.type';
import moment from 'moment';
import Week from './Week';
import Day from './Day';
import styles from './style';
const SCREEN_WIDTH = Dimensions.get('window').width;
const VIEW_INDEX = 1;
class CreateDays {
    constructor(currentDays, startDate, endDate) {
        this.currentDays = moment(currentDays);
        this.date = this.format('YYYY-MM-DD');
        this.title = this.IsMonthStart() ? `${this.format('M')}月` : this.format('D');
        this.isToday = this.IsToday();
        this.isMonthStart = this.IsMonthStart();
        this.disabled = this.IsExceed(startDate, endDate);
    }
    getMonthStartTime() {
        return this.currentDays.startOf('month').format('D');
    }
    format(format) {
        return this.currentDays.format(format);
    }
    IsToday() {
        return moment().format('YYYY-MM-DD') === this.currentDays.format('YYYY-MM-DD');
    }
    IsMonthStart() {
        return this.currentDays.format('D') === '1';
    }
    IsExceed(startDate, endDate) {
        return this.currentDays.isBetween(startDate, endDate);
    }
}
class CalenderContent extends Component {
    constructor() {
        super(...arguments);
        this.months = [];
        this.state = new typings.State(this.props);
        this.getDayProps = (renderIndex, befourOffset, currentMoment) => {
            const dayIndex = renderIndex - befourOffset;
            const currentDays = moment(currentMoment).add(dayIndex, 'day');
            const Days = new CreateDays(currentDays, this.props.startDate, this.props.endDate);
            return Object.assign({}, Days, { key: renderIndex, isSelected: this.state.selectedMoment.isSame(currentDays), onPress: () => {
                    this.selectDate(currentDays);
                    if (this.props.onDateClick) {
                        this.props.onDateClick(currentDays.format());
                    }
                }, style: {} });
        };
        /* 生成dataSource */
        this.getMonthes = (currentMoment) => {
            if (this.months.length === 0 && this.props.scrollEnabled) {
                this.fromCurrentMonth(currentMoment);
                return this.months;
            }
            else if (this.props.scrollEnabled) {
                this.fromNextMonth(currentMoment);
                return this.months;
            }
            return [moment(currentMoment)];
        };
        this.fromCurrentMonth = (currentMoment) => {
            // 第一次初始渲染的时候 1月 2月 3月 foucs
            for (let i = 0; i <= 2; i += 1) {
                const nextMoment = moment(currentMoment).add(i, 'month');
                if (moment(nextMoment).isBefore(this.props.endDate))
                    this.months.push(nextMoment);
            }
            return this.months;
        };
        this.fromNextMonth = (currentMoment) => {
            const startMoment = moment(this.props.startDate).startOf('month');
            // 第一次初始渲染后点击touch 避免重新渲染为 12月 1月 2月
            if (moment(currentMoment).isSame(startMoment))
                return this.months;
            this.months = [];
            for (let i = -VIEW_INDEX; i <= VIEW_INDEX; i += VIEW_INDEX) {
                this.months.push(moment(currentMoment).add(i, 'month'));
            }
            return this.months;
        };
        this.scrollToItem = (itemIndex) => {
            const scrollToX = itemIndex * SCREEN_WIDTH;
            if (this.props.scrollEnabled && this.calendar) {
                this.calendar.scrollTo({ y: 0, x: scrollToX, animated: false });
            }
        };
        this.scrollEnded = (event) => {
            let i;
            const startDate = moment(this.props.startDate).startOf('month');
            const endDate = moment(this.props.endDate).startOf('month');
            const currentMoment = this.state.currentMoment;
            const postion = event.nativeEvent.contentOffset.x;
            const next = postion / SCREEN_WIDTH;
            if (moment(startDate).isSame(currentMoment)) {
                // 初始化时 1 2 3  focus = 1  next=1时跳到2月
                i = next;
            }
            else if (next !== 1) {
                // 1 2 3 focus = 2 next=0 1月  next=2 3月 
                i = next === 0 ? -VIEW_INDEX : VIEW_INDEX;
            }
            const newMoment = moment(currentMoment).add(i, 'month');
            const isBetween = moment(newMoment).isBetween(startDate, endDate);
            if (isBetween) {
                this.setState({ currentMoment: newMoment });
                this.scrollToItem(VIEW_INDEX);
            }
        };
        this.selectDate = (date) => {
            this.setState({ selectedMoment: date });
        };
        this.renderCalendarView = (currentMoment) => {
            let renderIndex = 0; // 起始渲染位置
            let weekDate = []; // 保存一周的数据
            const weekStart = this.props.weekStart; // 从星期几开始
            const weekRows = []; // 保存每周的数据
            const currStartWeek = currentMoment.isoWeekday() - weekStart; // 每月第一天是从星期几开始做偏移
            const befourOffset = (currStartWeek + 7) % 7; // 偏移之前空几天
            for (renderIndex; renderIndex < 42; renderIndex += 1) {
                const element = this.renderDay(this.getDayProps(renderIndex, befourOffset, currentMoment));
                weekDate.push(element);
                if (renderIndex % 7 === 6) {
                    weekRows.push(React.createElement(Week, { style: this.props.style, key: `${renderIndex}-${currentMoment}` }, weekDate));
                    weekDate = [];
                }
            }
            return React.createElement(View, { style: { width: SCREEN_WIDTH }, key: `${currentMoment}` }, weekRows);
        };
        this.renderDay = (parameter) => {
            if (this.props.renderDay) {
                return this.props.renderDay(parameter);
            }
            return React.createElement(Day, Object.assign({}, parameter));
        };
    }
    render() {
        const { style } = this.props;
        const calendarDates = this.getMonthes(this.state.currentMoment);
        return (React.createElement(View, { style: [styles.container, style.container] },
            React.createElement(ScrollView, { ref: (calendar) => { this.calendar = calendar; }, horizontal: true, scrollEnabled: true, pagingEnabled: true, removeClippedSubviews: true, scrollEventThrottle: 1000, showsHorizontalScrollIndicator: false, automaticallyAdjustContentInsets: false, onMomentumScrollEnd: event => this.scrollEnded(event) }, calendarDates.map(month => this.renderCalendarView(month)))));
    }
}
CalenderContent.defaultProps = new typings.Props();
export default CalenderContent;
//# sourceMappingURL=index.js.map