import React, { Component } from 'react';
import { View, Text, TouchableOpacity } from 'react-native';
const styles = {
    common: {
        height: 40,
        marginTop: 8,
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: 'white'
    },
    raduis: {
        width: 5,
        height: 5,
        borderRadius: 2.5,
        backgroundColor: '#fff'
    },
    line: (width) => {
        return {
            width: width,
            opacity: .2,
            backgroundColor: '#fff',
            height: 5,
        };
    },
    selected: (marginLeft) => {
        return {
            flex: 1,
            marginLeft: marginLeft,
            flexDirection: 'row',
            height: 5, flexGrow: 0
        };
    },
    inRange: {
        flex: 1,
        height: 5,
        flexGrow: 0,
        justifyContent: 'space-between'
    },
    end: (marginRight) => {
        return {
            flex: 1,
            marginRight: marginRight,
            flexDirection: 'row',
            height: 5,
            flexGrow: 0
        };
    }
};
export default class Day extends Component {
    render() {
        let status = this.props.status;
        let onPress, textColor, activeStyle;
        if (this.props.disabled) {
            status = 'disabled';
            onPress = null;
        }
        else {
            onPress = () => {
                this.props.onDayPress(this.props.date);
            };
        }
        switch (status) {
            case 'disabled':
                textColor = '#e1e1e1';
                break;
            case 'common':
                textColor = '#666';
                break;
            case 'selected':
                textColor = '#fff';
                activeStyle = this.props.activeStart;
                break;
            case 'inRange':
                textColor = '#fff';
                activeStyle = this.props.activeInRange;
                break;
            case 'end':
                textColor = '#fff';
                activeStyle = this.props.activeEnd;
                break;
        }
        if (this.props.today)
            textColor = '#82A0FA';
        if (this.props.today && status == 'selected') {
            activeStyle = this.props.activeStart;
            textColor = '#fff';
        }
        if (this.props.today && status == 'inRange') {
            activeStyle = this.props.activeInRange;
            textColor = '#fff';
        }
        if (this.props.today && status == 'end') {
            activeStyle = this.props.activeEnd;
            textColor = '#fff';
        }
        const w1 = this.props.width / 14;
        const w2 = this.props.width / 7;
        const select = styles.selected(w1);
        const end = styles.end(w1);
        const line1 = styles.line(w1);
        const line2 = styles.line(w2);
        return (React.createElement(TouchableOpacity, { onPress: onPress, style: [styles.common, activeStyle, { width: w2 }] },
            React.createElement(Text, { style: [{ color: textColor, textAlign: 'center', fontWeight: 'bold', fontSize: 16 }] }, this.props.date.getDate()),
            status === 'selected' &&
                React.createElement(View, { style: select },
                    React.createElement(View, { style: styles.raduis }),
                    React.createElement(View, { style: line1 })),
            status === 'inRange' &&
                React.createElement(View, { style: styles.inRange },
                    React.createElement(View, { style: line2 })),
            status === 'end' &&
                React.createElement(View, { style: end },
                    React.createElement(View, { style: line1 }),
                    React.createElement(View, { style: styles.raduis }))));
    }
}
//# sourceMappingURL=index.js.map