import React, { Component } from 'react';
import { ListView, View } from 'react-native';
import Month from './Month';
import * as typings from './index.type';
import CalenderHeader from './CalenderHeader';
export default class CalenderPicker extends Component {
    constructor(props) {
        super(props);
        // 创建月份
        this.createMonths = (startDate, count) => {
            let monthIterator = startDate;
            const months = [];
            const startUTC = Date.UTC(startDate.getYear(), startDate.getMonth(), startDate.getDate());
            for (let i = 0; i < count; i++) {
                const dates = this.getDates(monthIterator);
                const today = new Date();
                months.push(dates.map((day) => {
                    const dateUTC = Date.UTC(day.getYear(), day.getMonth(), day.getDate());
                    return {
                        date: day,
                        today: today.toDateString() === day.toDateString(),
                        status: this.getStatus(day, this.selectFrom, this.selectTo),
                        disabled: day.getMonth() !== monthIterator.getMonth() || dateUTC < startUTC
                    };
                }));
                monthIterator.setMonth(monthIterator.getMonth() + 1);
            }
            return months;
        };
        // 点击回调函数
        this.changeSelection = (value) => {
            var { selectFrom, selectTo, months } = this;
            if (!selectFrom) {
                selectFrom = value;
            }
            else if (!selectTo) {
                if (value > selectFrom) {
                    selectTo = value;
                }
                else {
                    selectFrom = value;
                }
            }
            else if (selectFrom && selectTo) {
                selectFrom = value;
                selectTo = null;
            }
            months = months.map((month) => {
                return month.map((day) => {
                    return {
                        date: day.date,
                        today: day.today,
                        status: this.getStatus(day.date, selectFrom, selectTo),
                        disabled: day.disabled
                    };
                });
            });
            if (this.props.rangeSelect) {
                this.selectFrom = selectFrom;
                this.selectTo = selectTo;
            }
            else {
                this.selectFrom = this.selectTo = selectFrom;
            }
            this.months = months;
            this.props.onSelectionChange(value, this.prevValue);
            this.prevValue = value;
            this.setState({
                dataSource: this.state.dataSource.cloneWithRows(months)
            });
        };
        const { startDate, count, selectFrom, selectTo } = this.props;
        this.selectFrom = selectFrom;
        this.selectTo = selectTo;
        this.months = this.createMonths(startDate, count); // [[1月数据],[2月数据],[3],[4],....]
        this.state = new typings.State(new ListView.DataSource({ rowHasChanged: this.rowHasChanged }), this.months);
    }
    rowHasChanged(r1, r2) {
        let statue = false;
        for (var i = 0; i < r1.length; i++) {
            if (r1[i].status !== r2[i].status && !r1[i].disabled) {
                statue = true;
            }
        }
        return statue;
    }
    // 获取每月的天数
    getDates(month) {
        const allDates = [];
        month = new Date(month);
        month.setDate(1);
        const startDate = this.getStartDate(month);
        const lastDate = this.getLastDate(month);
        while (startDate <= lastDate) {
            allDates.push(new Date(startDate));
            startDate.setDate(startDate.getDate() + 1);
        }
        return allDates;
    }
    // 月头补齐后的开始天数
    getStartDate(month) {
        let delta = month.getDay() - 1;
        if (delta === -1)
            delta = 6;
        const startDate = new Date(month);
        startDate.setDate(startDate.getDate() - delta);
        return startDate;
    }
    // 月末补齐后的最后一天
    getLastDate(month) {
        month.setMonth(month.getMonth() + 1);
        month.setDate(0);
        let delta = 6 - month.getDay() + 1;
        if (delta === 7)
            delta = 0;
        const lastDate = new Date(month);
        lastDate.setDate(lastDate.getDate() + delta);
        return lastDate;
    }
    // 判断date的状态
    getStatus(date, selectFrom, selectTo) {
        if (selectFrom) {
            if (selectFrom.toDateString() === date.toDateString()) {
                return 'selected';
            }
        }
        if (selectTo) {
            if (selectTo.toDateString() === date.toDateString()) {
                return 'end';
            }
        }
        if (selectFrom && selectTo) {
            if (selectFrom < date && date < selectTo) {
                return 'inRange';
            }
        }
        return 'common';
    }
    render() {
        return (React.createElement(View, { style: { width: this.props.width } },
            React.createElement(CalenderHeader, { weekData: this.props.weekData, style: { header: { width: this.props.width } } }),
            React.createElement(ListView, { initialListSize: 5, scrollRenderAheadDistance: 1200, dataSource: this.state.dataSource, renderRow: (month) => {
                    return (React.createElement(Month, Object.assign({}, this.props, { dataSource: month, changeSelection: this.changeSelection })));
                } })));
    }
}
CalenderPicker.defaultProps = new typings.Props();
//# sourceMappingURL=index.js.map