var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import React, { Component, } from 'react';
import { View, Text, } from 'react-native';
import lodash from 'lodash';
import * as typings from './type';
import styles from './style';
/**
 * @desc border正则, 就是为了获取字符串中 width 和 color
 */
const BORDER_REGEXP = [
    { key: 'width', regexp: /\d+/ },
    { key: 'color', regexp: /#\w+/ },
];
/**
 * @param {string} borderStr 形如 '2 #ccc'
 * @return { width, color} 只有一个宽高
 * @desc 根据字符串获取宽高
 */
const getBorderStyle = (borderStr) => {
    const style = {};
    let bds = borderStr;
    for (let i = 0; i < BORDER_REGEXP.length; i += 1) {
        const prop = BORDER_REGEXP[i];
        if (prop.regexp.test(bds)) {
            bds = bds.replace(prop.regexp, (match) => {
                style[prop.key] = prop.key === 'width' ? +match : match;
            });
        }
    }
    return style;
};
/**
 * @param {number} flex 占位符flex
 * @param {width, color} borderStyle 占位格子宽度和颜色
 * @param {style} gridsStyle 样式, 继承自最后一排第一个
 * @desc 画占位格子
 */
const gridHolder = (flex, borderStyle, gridsStyle) => {
    // gird 设置padding 的话, 这里需要比较复杂的操作,
    // 因为懒,所以我们给用户的选择是: 不要写 padding margin border 相关属性
    const paddingRight = ((flex - 1) * (borderStyle.width));
    /**waring flex报错 */
    return (React.createElement(View, { key: "_unique_holder", style: [{
                flex,
                paddingRight,
                borderLeftColor: borderStyle.color,
                borderLeftWidth: borderStyle.width
            },
            gridsStyle,
        ] }));
};
/**
 * @param {Grid} children 内部Grid
 * @param {string} border 就那个string
 * @param {style} gridStyle 格子的样式
 * @desc 画格子们
 */
const renderGrids = (children, border, gridStyle) => (Array.isArray(children)
    ? children.map(({ props }, index) => {
        const idxKey = index;
        return React.createElement(Grid, Object.assign({ key: idxKey }, props, { border: border, style: [gridStyle, props.style] }));
    })
    : React.createElement(Grid, Object.assign({}, children.props, { border: border, style: [gridStyle, children.props.style] })));
/**
 * @param {Grid} children
 * @param {num} col 每列显示的个数
 * @param {string} border 就那个border样式,只有width 和 color
 * @param {number} gridStyle 格子的样式
 * @desc 画一行行格子里面的行
 */
const renderRows = (children, col, border, gridStyle) => {
    if (Array.isArray(children)) {
        const rows = lodash.chunk(children, col);
        const borderStyle = getBorderStyle(border);
        return rows.map((grids, index) => {
            const isLast = index === rows.length - 1;
            if (isLast) {
                const blankFlex = col - grids.length;
                const blankStyle = Object.assign({}, gridStyle, grids[grids.length - 1].props.style);
                if (blankFlex > 0)
                    grids.push(gridHolder(blankFlex, borderStyle, blankStyle));
            }
            const idxKey = index;
            return (React.createElement(View, { key: idxKey, style: styles.row(borderStyle.width, borderStyle.color) }, renderGrids(grids, border, gridStyle)));
        });
    }
    if (typeof children === 'string') {
        return React.createElement(Text, null, children);
    }
    return children;
};
class Grid extends Component {
    render() {
        const isRoot = !!(Array.isArray(this.props.children)
            && this.props.children.find(({ type }) => type === Grid));
        const _a = this.props, { children, col, border, grid } = _a, others = __rest(_a, ["children", "col", "border", "grid"]);
        const borderStr = border === true ? '1 #cecece' : border;
        const borderStyle = getBorderStyle(borderStr);
        return (React.createElement(View, Object.assign({}, others, { style: [isRoot
                    ? styles.rootGrid(borderStyle.width, borderStyle.color)
                    : styles.grid(borderStyle.width, borderStyle.color),
                this.props.style] }), renderRows(children, col, borderStr, grid)));
    }
}
Grid.defaultProps = new typings.Props();
export default Grid;
//# sourceMappingURL=index.js.map