import React from 'react';
import { Text, TouchableWithoutFeedback, View, } from 'react-native';
import { isEqual } from '../Tools';
const NOOP = () => { };
export class Props {
    constructor() {
        this.multiple = false;
        this.onChange = NOOP;
    }
}
const Select = (props) => {
    // let props.children = children;
    // 兼容单个选项
    if (!Array.isArray(props.children)) {
        props.children = props.children ? [props.children] : [];
    }
    const _values = [];
    const _selected = [];
    const onSelect = (index) => {
        // 未定义回调
        if (props.onChange === undefined)
            return;
        // 单选
        if (!props.multiple) {
            props.onChange(_values[index], index);
            return;
        }
        // 切换状态
        if (index in _selected) {
            delete _selected[index];
        }
        else {
            _selected[index] = _values[index];
        }
        // 执行回调
        props.onChange(_selected.filter(option => option !== undefined), Object.keys(_selected));
    };
    const isSelected = ({ props: itemProps }, index) => {
        // 判断 selected
        let isTrue = props.value === undefined && itemProps.selected; // eslint-disable-line
        // 判断 value
        if (props.multiple) {
            isTrue = isTrue || props.value.findIndex(_value => isEqual(_value, itemProps.value)) !== -1;
        }
        else {
            if (_selected.length > 1)
                return false;
            isTrue = isTrue || isEqual(props.value, itemProps.value);
        }
        // 处理选中
        if (isTrue) {
            _selected[index] = itemProps.value;
            return true;
        }
        return false;
    };
    // 界面渲染
    return (React.createElement(View, { style: props.style }, props.children.map((item, index) => {
        const key = index;
        let item$ = item;
        // 未设置 value 则取 children
        if (item$.type === Text && item$.props.value === undefined) {
            item$ = React.createElement(Text, Object.assign({}, item$.props, { value: item$.props.children }));
        }
        // 填充 _values 相应键值
        _values[index] = item$.props.value;
        // 是否选中
        const itemSelected = isSelected(item$, index);
        // Text 兼容
        if (item$.type === Text) {
            item$ = (React.createElement(View, { style: { flexDirection: 'row', justifyContent: 'space-between', alignItems: 'center' } },
                React.createElement(Text, Object.assign({}, item$.props, { style: [{ backgroundColor: 'transparent' }, item$.props.style] })),
                itemSelected ? React.createElement(Text, null, "-") : null));
        }
        // 渲染单条
        return (React.createElement(TouchableWithoutFeedback, { onPress: () => onSelect(index), key: key },
            React.createElement(View, null,
                React.createElement(item$.type, Object.assign({}, item$.props, { selected: itemSelected })))));
    })));
};
Select.defaultProps = new Props();
export default Select;
// export default class Select extends Component<PropDefine, {}> {
//   static defaultProps = new Props();
//   private _values = [];
//   private _selected = [];
//   /**
//    * 选中某一条(index)
//    * @memberof Select
//    */
//   onSelect = (index: number) => {
//     const { _values, _selected, props } = this;
//     // 单选
//     if (!props.multiple) {
//       props.onChange(_values[index], index);
//       return;
//     }
//     // 切换状态
//     if (index in _selected) {
//       delete _selected[index];
//     } else {
//       _selected[index] = _values[index];
//     }
//     // 执行回调
//     props.onChange(_selected.filter(option => option !== undefined), Object.keys(_selected));
//   }
//   /**
//    * 判断item是否被选中
//    * @memberof Select
//    */
//   isSelected = (itemInstance: any, index: number) => {
//     const { props } = this; 
//     const { props: itemProps } = itemInstance;
//     if (!itemProps) return false;
//     // 判断 selected 
//     let isTrue: any = props.value === undefined && itemProps.selected;
//     // 判断 value
//     if (props.multiple) {
//       isTrue = isTrue || props.value.findIndex(_value => isEqual(_value, itemProps.value)) !== -1;
//     } else {
//       if (this._selected.length > 1) return false;
//       isTrue = isTrue || isEqual(props.value, itemProps.value);
//     }
//     // 处理选中
//     if (isTrue) {
//       this._selected[index] = props.value;
//       return true;
//     }
//     return false;
//   }
//   /**
//    * 渲染条子们
//    * @memberof Select
//    */
//   renderItems = (): ReactNode => {
//     const { props } = this;
//     const arrayChildren = Array.isArray(props.children)
//       ? props.children
//       : props.children
//         ? [props.children]
//         : [];
//     return arrayChildren.map((item: any, index: number) => {
//       return this.renderItem(item, index);
//     });
//   }
//   /**
//    * 渲染单个item
//    * @memberof Select
//    */
//   renderItem = (item: any, index: number): ReactNode => {
//     let itemInstance = item;
//     if (itemInstance.type === Text && itemInstance.props.value === undefined) {
//       itemInstance  = <Text {...itemInstance.props} value={itemInstance.props.children} />;
//     }
//     this._values[index] = itemInstance.props.value;
//     const isSelected = this.isSelected(itemInstance, index);
//     // Text 兼容
//     if (itemInstance.type === Text) {
//       itemInstance = (
//         <View style={styles.textItem}>
//           <Text
//             {...itemInstance.props}
//             style={[{ backgroundColor: 'transparent' }, itemInstance.props.style]}
//           />
//           {isSelected ? <Text>√</Text> : null}
//         </View>
//       );
//     }
//     const onItemPress = () => this.onSelect(index);
//     return (
//       <TouchableWithoutFeedback onPress={onItemPress} key={index}>
//         <View>
//           <itemInstance.type {...itemInstance.props} selected={isSelected} />
//         </View>
//       </TouchableWithoutFeedback>
//     );
//   }
//   render() {
//     const { style } = this.props;
//     return (
//       <View style={style}>
//         {this.renderItems()}
//       </View>
//     );
//   }
// }
//# sourceMappingURL=index.js.map