/**
 * 下方弹出框
 * @CopyLeft [rnx-ui](https://github.com/rnxteam/rnx-ui/tree/master/Sheet)
 */
import React, { Component, } from 'react';
import { StyleSheet, View, Animated, } from 'react-native';
import Overlay from '../Overlay';
const NOOP = () => { };
export class SheetDefaultProp {
    constructor() {
        this.style = null;
        this.visible = false;
        this.overlayStyle = null;
        this.onClose = NOOP;
        this.onPressOverlay = NOOP;
        this.children = null;
        this.duration = 200;
    }
}
const styles = StyleSheet.create({
    container: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        right: 0,
        height: 0,
    },
    sheet: {
        position: 'absolute',
        left: 0,
        right: 0,
    },
});
export default class Sheet extends Component {
    constructor(props) {
        super(props);
        this.getHeight = (e) => {
            const { height } = e.nativeEvent.layout;
            if (height !== this.height) {
                this.height = height;
                this.aniShow = this.makeAnimation(-height);
            }
        };
        this.makeAnimation = (toValue) => {
            return Animated.timing(this.state.animDistance, {
                toValue,
                duration: this.props.duration,
            });
        };
        // 显示
        this.show = () => {
            if (this.height === null) {
                // 如果组件还未渲染，等待，再次尝试
                setTimeout(() => {
                    this.show();
                }, 10);
                return;
            }
            this.aniHide.stop();
            this.aniShow.start();
        };
        // 隐藏
        this.hide = () => {
            this.aniShow.stop();
            this.aniHide.start((e) => {
                if (e.finished) {
                    this.setState({
                        overlayVisible: false,
                    });
                    this.props.onClose();
                }
            });
        };
        this.state = {
            overlayVisible: props.visible,
            animDistance: new Animated.Value(0),
        };
        this.height = null;
        this.aniShow = this.makeAnimation(this.height || 0);
        this.aniHide = this.makeAnimation(0);
        this.getHeight = this.getHeight.bind(this);
    }
    componentWillMount() {
        if (this.props.visible) {
            this.show();
        }
    }
    componentWillReceiveProps(props) {
        if (props.visible && !this.props.visible) {
            // 隐藏 -> 显示
            this.setState({
                overlayVisible: true,
            });
            this.show();
        }
        else if (!props.visible && this.props.visible) {
            // 显示 -> 隐藏
            this.hide();
        }
    }
    render() {
        return (React.createElement(Overlay, { visible: this.state.overlayVisible, style: this.props.overlayStyle, onPress: this.props.onPressOverlay },
            React.createElement(View, { style: styles.container },
                React.createElement(Animated.View, { style: [styles.sheet, { top: this.state.animDistance }, this.props.style], onLayout: this.getHeight }, this.props.children))));
    }
}
Sheet.defaultProps = new SheetDefaultProp();
//# sourceMappingURL=index.js.map