import React, { Component, } from 'react';
import { Animated, Text, View, Dimensions, } from 'react-native';
import styles from './style';
import Touch from '../Touch';
const NOOP = () => { };
const DEVICE_WIDTH = Dimensions.get('window').width;
export class TabBarDefaultProps {
    constructor() {
        this.tabs = [];
        this.activeTextStyle = styles.activeTextStyle;
        this.defaultTextStyle = null;
        this.tabBarStyle = styles.defaultTabBarStyle;
        this.tabUnderLineStyle = null;
        this.goToScene = NOOP;
        this.activeTab = null;
    }
}
export class TabBarDefaultStates {
    constructor(offset, marginLeft) {
        this.tabWidth = 0;
        this.offset = this.offset;
        this.prevActive = 0;
        this.marginLeft = this.marginLeft;
        this.offset = offset;
        this.marginLeft = marginLeft;
    }
}
export default class TabBar extends Component {
    constructor(props) {
        super(props);
        this.onPress = (key, onPressHandler) => {
            onPressHandler(key);
            this._Animated(key);
        };
        this._Animated = (index) => {
            const len = this.props.tabs.length;
            Animated.spring(this.state.offset, {
                toValue: index * (DEVICE_WIDTH / len),
            }).start();
        };
        this.renderTab = (tabLabel, key, onPressHandler) => {
            const { activeTextStyle, defaultTextStyle, activeTab, } = this.props;
            const onPress = () => {
                this.onPress(key, onPressHandler);
            };
            return (React.createElement(Touch, { style: [{ flex: 1 }], key: tabLabel + key, accessible: true, accessibilityLabel: tabLabel, accessibilityTraits: "button", onPress: onPress },
                React.createElement(View, { style: styles.item },
                    React.createElement(View, { style: styles.tabBackground },
                        React.createElement(Text, { style: activeTab === key ? activeTextStyle : defaultTextStyle }, tabLabel)))));
        };
        const itemWidth = DEVICE_WIDTH / props.tabs.length;
        const marginLeft = (itemWidth - props.tabUnderLineStyle.width) / 2;
        this.state = new TabBarDefaultStates(new Animated.Value(0), marginLeft);
    }
    componentWillUpdate(nextProps) {
        this._Animated(nextProps.activeTab);
    }
    render() {
        const { tabs, goToScene, tabBarStyle, tabUnderLineStyle, } = this.props;
        const tabWidth = DEVICE_WIDTH / tabs.length;
        const animatedStyle = { width: tabWidth, transform: [{ translateX: this.state.offset }] };
        return (React.createElement(View, null,
            React.createElement(View, { style: [styles.defaultTabBarStyle, tabBarStyle] }, tabs.map((tabLabel, key) => this.renderTab(tabLabel, key, goToScene))),
            React.createElement(Animated.View, { style: [styles.showUnderline, animatedStyle] },
                React.createElement(View, { style: [tabUnderLineStyle, { marginLeft: this.state.marginLeft }] }))));
    }
}
TabBar.defaultProps = new TabBarDefaultProps();
//# sourceMappingURL=index.js.map